"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SetOracleName = exports.GetOracleName = exports.DeleteAttestation = exports.DeleteAnnouncement = exports.GetSignatures = exports.SignDigits = exports.SignEnum = exports.CreateNumericAnnouncement = exports.CreateEnumAnnouncement = exports.GetAnnouncement = exports.SignMessage = exports.ListAnnouncements = exports.ExportStakingAddressWIF = exports.GetStakingAddress = exports.GetPublicKey = void 0;
const index_js_1 = require("common-ts/index.js");
const message_util_js_1 = require("common-ts/util/message-util.js");
const validation_util_js_1 = require("common-ts/util/validation-util.js");
const validation_util_js_2 = require("./util/validation-util.js");
// Expose all 'common' endpoints
__exportStar(require("common-ts/index.js"), exports);
/** Specific Oracle Server message functions */
function GetPublicKey() {
    console.debug('GetPublicKey()');
    const m = (0, message_util_js_1.getMessageBody)("getpublickey" /* MessageType.getpublickey */);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.GetPublicKey = GetPublicKey;
function GetStakingAddress() {
    console.debug('GetStakingAddress()');
    const m = (0, message_util_js_1.getMessageBody)("getstakingaddress" /* MessageType.getstakingaddress */);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.GetStakingAddress = GetStakingAddress;
function ExportStakingAddressWIF() {
    console.debug('ExportStakingAddressWIF()');
    const m = (0, message_util_js_1.getMessageBody)("exportstakingaddresswif" /* MessageType.exportstakingaddresswif */);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.ExportStakingAddressWIF = ExportStakingAddressWIF;
function ListAnnouncements() {
    console.debug('ListAnnouncements()');
    const m = (0, message_util_js_1.getMessageBody)("listannouncements" /* MessageType.listannouncements */);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.ListAnnouncements = ListAnnouncements;
function SignMessage(message) {
    console.debug('SignMessage()', message);
    (0, validation_util_js_1.validateString)(message, 'SignMessage()', 'message');
    const m = (0, message_util_js_1.getMessageBody)("signmessage" /* MessageType.signmessage */, [message]);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.SignMessage = SignMessage;
function GetAnnouncement(eventName) {
    console.debug('GetAnnouncement()', eventName);
    (0, validation_util_js_1.validateString)(eventName, 'GetAnnouncement()', 'eventName');
    const m = (0, message_util_js_1.getMessageBody)("getannouncement" /* MessageType.getannouncement */, [eventName]);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.GetAnnouncement = GetAnnouncement;
function CreateEnumAnnouncement(eventName, maturationTimeISOString, outcomes) {
    console.debug('CreateEnumAnnouncement()', eventName, maturationTimeISOString, outcomes);
    (0, validation_util_js_1.validateString)(eventName, 'CreateEnumAnnouncement()', 'eventName');
    (0, validation_util_js_1.validateISODateString)(maturationTimeISOString, 'CreateEnumAnnouncement()', 'maturationTimeISOString');
    (0, validation_util_js_2.validateEnumOutcomes)(outcomes, 'CreateEnumAnnouncement()');
    const m = (0, message_util_js_1.getMessageBody)("createenumannouncement" /* MessageType.createenumannouncement */, [eventName, maturationTimeISOString, outcomes]);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.CreateEnumAnnouncement = CreateEnumAnnouncement;
function CreateNumericAnnouncement(eventName, maturationTimeISOString, minValue, maxValue, unit, precision) {
    console.debug('CreateNumericAnnouncement()', eventName, maturationTimeISOString, minValue, maxValue, unit, precision);
    (0, validation_util_js_1.validateString)(eventName, 'CreateNumericAnnouncement()', 'eventName');
    (0, validation_util_js_1.validateISODateString)(maturationTimeISOString, 'CreateNumericAnnouncement()', 'maturationTimeISOString');
    (0, validation_util_js_1.validateNumber)(minValue, 'CreateNumericAnnouncement()', 'minValue');
    (0, validation_util_js_1.validateNumber)(maxValue, 'CreateNumericAnnouncement()', 'maxValue');
    // TODO : Validate minValue/maxValue?
    (0, validation_util_js_1.validateString)(unit, 'CreateNumericAnnouncement()', 'unit'); // unit can be an empty string
    (0, validation_util_js_1.validateNumber)(precision, 'CreateNumericAnnouncement()', 'precision');
    if (precision < 0)
        throw (Error('CreateNumericAnnouncement() precision must be >= 0'));
    const m = (0, message_util_js_1.getMessageBody)("createnumericannouncement" /* MessageType.createnumericannouncement */, [eventName, maturationTimeISOString, minValue, maxValue, unit, precision]);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.CreateNumericAnnouncement = CreateNumericAnnouncement;
function SignEnum(eventName, outcome) {
    console.debug('SignEnum()', eventName, outcome);
    (0, validation_util_js_1.validateString)(eventName, 'SignEnum()', 'eventName');
    (0, validation_util_js_1.validateString)(outcome, 'SignEnum()', 'outcome');
    const m = (0, message_util_js_1.getMessageBody)("signenum" /* MessageType.signenum */, [eventName, outcome]);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.SignEnum = SignEnum;
function SignDigits(eventName, outcome) {
    console.debug('SignDigits()', eventName, outcome);
    (0, validation_util_js_1.validateString)(eventName, 'SignDigits()', 'eventName');
    (0, validation_util_js_1.validateNumber)(outcome, 'SignDigits()', 'outcome');
    const m = (0, message_util_js_1.getMessageBody)("signdigits" /* MessageType.signdigits */, [eventName, outcome]);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.SignDigits = SignDigits;
function GetSignatures(eventName) {
    console.debug('GetSignatures()', eventName);
    (0, validation_util_js_1.validateString)(eventName, 'GetSignatures()', 'eventName');
    const m = (0, message_util_js_1.getMessageBody)("getsignatures" /* MessageType.getsignatures */, [eventName]);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.GetSignatures = GetSignatures;
function DeleteAnnouncement(eventName) {
    console.debug('DeleteAnnouncement()', eventName);
    (0, validation_util_js_1.validateString)(eventName, 'DeleteAnnouncement()', 'eventName');
    const m = (0, message_util_js_1.getMessageBody)("deleteannouncement" /* MessageType.deleteannouncement */, [eventName]);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.DeleteAnnouncement = DeleteAnnouncement;
function DeleteAttestation(eventName) {
    console.debug('DeleteAttestation()', eventName);
    (0, validation_util_js_1.validateString)(eventName, 'DeleteAttestation()', 'eventName');
    const m = (0, message_util_js_1.getMessageBody)("deleteattestation" /* MessageType.deleteattestation */, [eventName]);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.DeleteAttestation = DeleteAttestation;
function GetOracleName() {
    console.debug('GetOracleName()');
    const m = (0, message_util_js_1.getMessageBody)("getoraclename" /* MessageType.getoraclename */);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.GetOracleName = GetOracleName;
function SetOracleName(oracleName) {
    console.debug('SetOracleName()', oracleName);
    const m = (0, message_util_js_1.getMessageBody)("setoraclename" /* MessageType.setoraclename */, [oracleName]);
    return (0, index_js_1.SendServerMessage)(m).then(response => {
        return response;
    });
}
exports.SetOracleName = SetOracleName;
//# sourceMappingURL=index.js.map