"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.announcementTests = void 0;
const assert_1 = __importDefault(require("assert"));
const OracleServer = __importStar(require("../index"));
const validationUtil = __importStar(require("../util/validation-util"));
const ENUM_NAME = 'enum_' + validationUtil.makeId(4);
const NUMERIC_NAME = 'numeric_' + validationUtil.makeId(4);
let minDate = new Date();
minDate.setDate(minDate.getDate() + 1);
const OUTCOME_1 = 'outcome1';
const OUTCOME_2 = 'outcome2';
const OUTCOME_3 = 'outcome3';
const NUMERIC_MIN = 0;
const NUMERIC_MAX = 100;
const NUMERIC_OUTCOME = validationUtil.getRandomInt(NUMERIC_MIN, NUMERIC_MAX);
const VALID_ENUM_EVENT = [ENUM_NAME, minDate.toISOString(), [OUTCOME_1, OUTCOME_2]];
const VALID_NUMERIC_EVENT = [NUMERIC_NAME, minDate.toISOString(), NUMERIC_MIN, NUMERIC_MAX, 'units', 0];
// await only likes to be used in async functions
function announcementTests() {
    return __awaiter(this, void 0, void 0, function* () {
        yield OracleServer.CreateEnumAnnouncement(...VALID_ENUM_EVENT).then(r => {
            console.debug(`CreateEnumAnnouncement ${ENUM_NAME} response:`, r);
            (0, assert_1.default)(r.result);
            assert_1.default.ifError(r.error);
            OracleServer.GetAnnouncement(ENUM_NAME).then((r) => __awaiter(this, void 0, void 0, function* () {
                console.debug(`GetAnnouncement ${ENUM_NAME} response:`, r);
                (0, assert_1.default)(r.result);
                assert_1.default.ifError(r.error);
                assert_1.default.equal(r.result.eventName, ENUM_NAME);
                yield OracleServer.ListAnnouncements().then(r => {
                    console.debug(`ListAnnouncements ${ENUM_NAME} response:`, r);
                    (0, assert_1.default)(r.result);
                    assert_1.default.ifError(r.error);
                    (0, assert_1.default)(r.result.indexOf(ENUM_NAME) !== -1);
                });
                // Test sign non-existent outcome
                yield assert_1.default.rejects(() => OracleServer.SignEnum(ENUM_NAME, OUTCOME_3));
                OracleServer.SignEnum(ENUM_NAME, OUTCOME_1).then((r) => __awaiter(this, void 0, void 0, function* () {
                    console.debug(`SignEnum ${ENUM_NAME} ${OUTCOME_1} response:`, r);
                    (0, assert_1.default)(r.result);
                    assert_1.default.ifError(r.error);
                    // Test re-sign
                    yield assert_1.default.rejects(() => OracleServer.SignEnum(ENUM_NAME, OUTCOME_2));
                    OracleServer.GetAnnouncement(ENUM_NAME).then((r) => __awaiter(this, void 0, void 0, function* () {
                        console.debug(`GetAnnouncement ${ENUM_NAME} response:`, r);
                        (0, assert_1.default)(r.result);
                        assert_1.default.ifError(r.error);
                        assert_1.default.equal(r.result.eventName, ENUM_NAME);
                        assert_1.default.equal(r.result.signedOutcome, OUTCOME_1);
                        // Cannot delete yet because the Announcement is signed
                        yield assert_1.default.rejects(() => OracleServer.DeleteAnnouncement(ENUM_NAME));
                        OracleServer.DeleteAttestation(ENUM_NAME).then(r => {
                            console.debug(`DeleteAttestation ${ENUM_NAME} response:`, r);
                            (0, assert_1.default)(r.result);
                            assert_1.default.ifError(r.error);
                            OracleServer.DeleteAnnouncement(ENUM_NAME).then(r => {
                                console.debug(`DeleteAnnouncement ${ENUM_NAME} response:`, r);
                                (0, assert_1.default)(r.result);
                                assert_1.default.ifError(r.error);
                            });
                        });
                    }));
                }));
            }));
        });
        yield OracleServer.CreateNumericAnnouncement(...VALID_NUMERIC_EVENT).then(r => {
            console.debug(`CreateNumericAnnouncement ${NUMERIC_NAME} response:`, r);
            (0, assert_1.default)(r.result);
            assert_1.default.ifError(r.error);
            OracleServer.GetAnnouncement(NUMERIC_NAME).then((r) => __awaiter(this, void 0, void 0, function* () {
                console.debug(`GetAnnouncement ${NUMERIC_NAME} response:`, r);
                (0, assert_1.default)(r.result);
                assert_1.default.ifError(r.error);
                assert_1.default.equal(r.result.eventName, NUMERIC_NAME);
                yield OracleServer.ListAnnouncements().then(r => {
                    console.debug(`ListAnnouncements ${NUMERIC_NAME} response:`, r);
                    (0, assert_1.default)(r.result);
                    assert_1.default.ifError(r.error);
                    (0, assert_1.default)(r.result.indexOf(NUMERIC_NAME) !== -1);
                });
                OracleServer.SignDigits(NUMERIC_NAME, NUMERIC_OUTCOME).then((r) => __awaiter(this, void 0, void 0, function* () {
                    console.debug(`SignDigits ${NUMERIC_NAME} ${NUMERIC_OUTCOME} response:`, r);
                    (0, assert_1.default)(r.result);
                    assert_1.default.ifError(r.error);
                    // Cannot delete yet because the Announcement is signed
                    yield assert_1.default.rejects(() => OracleServer.DeleteAnnouncement(NUMERIC_NAME));
                    OracleServer.GetAnnouncement(NUMERIC_NAME).then((r) => __awaiter(this, void 0, void 0, function* () {
                        console.debug(`GetAnnouncement ${NUMERIC_NAME} response:`, r);
                        (0, assert_1.default)(r.result);
                        assert_1.default.ifError(r.error);
                        assert_1.default.equal(r.result.eventName, NUMERIC_NAME);
                        assert_1.default.equal(r.result.signedOutcome, NUMERIC_OUTCOME);
                        // Cannot delete yet because the Announcement is signed
                        yield assert_1.default.rejects(() => OracleServer.DeleteAnnouncement(NUMERIC_NAME));
                        OracleServer.DeleteAttestation(NUMERIC_NAME).then(r => {
                            console.debug(`DeleteAttestation ${NUMERIC_NAME} response:`, r);
                            (0, assert_1.default)(r.result);
                            assert_1.default.ifError(r.error);
                            OracleServer.DeleteAnnouncement(NUMERIC_NAME).then(r => {
                                console.debug(`DeleteAnnouncement ${NUMERIC_NAME} response:`, r);
                                (0, assert_1.default)(r.result);
                                assert_1.default.ifError(r.error);
                            });
                        });
                    }));
                }));
            }));
        });
        // TODO : Testing signing behavior past min/max bounds
    });
}
exports.announcementTests = announcementTests;
//# sourceMappingURL=announcement-tests.js.map